clear
set more off

***********************Why Randomize***********************
*We will use different methods to calcualte impact
*First Example: We will calculate the pre-post estimate
*Second Example: We will calcualte the simple difference
*Third Example: We will calculate difference-in-difference
*Fourth Example: We will do regression analysis


***important variables
*freeclasses  1 if child is taking free classes, 0 if not
*readlevel_base  childs reading level on a scale of 0-5, before intervention
*readlevel_mid  childs reading level on a scale of 0-5, after intervention

*Set directory (command: "cd")
cd "C:\Users\hirasid\Dropbox\Rachels Book\Website\Ch2_Why\Exercise_WhyRandomize_Stata"
use LearnToRead.dta, clear


***Part 1: Pre-Post***

*Calculate mean test scores for children taking free classes before intervention (Pre)
summarize readlevel_base if freeclasses==1
local mean_pre = r(mean)


*Calculate mean test scores for children taking free classes after intervention (Post)
summarize readlevel_mid if freeclasses==1
local mean_post = r(mean)

*Display the difference in means
display `mean_pre - `mean_post

*Calculate t-test
ttest readlevel_base == readlevel_mid if freeclasses==1

*Calculate estimate using regression, with clustered standard errors
gen readlevel_difference = readlevel_base - readlevel_mid

reg readlevel_difference if freeclasses == 1, vce(cl panchayatid) 


***Part 2: Simple Difference***

*Calculate mean test scores for children taking free classes after intervention 
summarize readlevel_mid if freeclasses==1
local mean_post_class = r(mean)

*Calculate mean test scores for children nto taking free classes after intervention
summarize readlevel_mid if freeclasses==0
local mean_post_noclass = r(mean)

*Display the difference in means
display `mean_post_class - `mean_post_noclass

*Calculate t-test
ttest readlevel_mid, by(freeclasses)

*Calculate estimate using regression, wth clustered standard errors
reg readlevel_mid freeclasses, vce (cl panchayatid)


***Part 3: DIFFERENCE IN DIFFERENCE ESTIMATION***

*Calculate Mean test scores for children taking free classes before intervention
summarize readlevel_base if freeclasses==1
local mean_pre_class = r(mean)

*Calculate Mean test scores for children taking free classes after intervention
summarize readlevel_mid if freeclasses==1
local mean_post_class = r(mean)

*Calculate Mean test scores for children not taking free classes before intervention
summarize readlevel_base if freeclasses==0
local mean_pre_noclass = r(mean)

*Calculate Mean test scores for children not taking free classes after intervention
summarize readlevel_mid if freeclasses==0
local mean_post_noclass = r(mean)

*Calculate t-test
ttest readlevel_diff, by(freeclasses)

*Calculate estimate using regression, with clustered standard errors
reg readlevel_diff freeclasses, vce (cl panchayatid)


***Part 4: REGRESSION ANALYSIS***

*Create a local for all controls

local controls readlevel_base age sex standard schooltype_govt schooltype_private schooltype_ngo schooltype_madrassa literate

*Calculate estimate using regression without controls
reg readlevel_mid freeclasses, vce(cl panchayatid)

*Calculate estimate using regression with previous reading level as control
reg readlevel_mid freeclasses readlevel_base, vce(cl panchayatid)

*Calculate estimate using regression with previous reading level and other controls
reg readlevel_mid freeclasses `controls', vce(cl panchayatid)


***Part 5: REGRESSION ANALYSIS given Random Assignment***

*Set directory (command: "cd")
cd "C:\Users\hirasid\Dropbox\Rachels Book\Website\Ch2_Why\Exercise_WhyRandomize_Stata"
use LearnToRead_RCT.dta, clear

*Create a local for all controls

local controls readlevel_base age sex standard schooltype_govt schooltype_private schooltype_ngo schooltype_madrassa literate

*Calculate estimate using regression without controls
reg readlevel_mid treatment, vce(cl panchayatid)

*Calculate estimate using regression with previous reading level as control
reg readlevel_mid treatment readlevel_base, vce(cl panchayatid)

*Calculate estimate using regression with previous reading level and other controls
reg readlevel_mid treatment `controls', vce(cl panchayatid)
